_antonyms = {
    "capacidad": "incapacidad",
    "anormal": "normal",
    "abolir": "establecer",
    "ausencia": "presencia",
    "ausente": "presente",
    "futuro": "retrospectivo",
    "absoluto": "relativo",
    "abstenerse": "consumir",
    "abstracto": "hormigón",
    "abundancia": "escasez",
    "abundante": "escaso",
    "aceptar": "rechazar",
    "admitir": "negar",
    "aceptable": "inaceptable",
    "aceptación": "rechazo",
    "accesible": "inaccesible",
    "preciso": "incorrecto",
    "admitido": "no reconocido",
    "conocido": "desconocido",
    "acto": "estribillo",
    "acción": "en acción",
    "activo": "tranquilo",
    "existente": "inexistente",
    "ruidoso": "tranquilo",
    "actividad": "inactividad",
    "real": "irreal",
    "añadir": "sustraer",
    "adición": "sustracción",
    "adecuado": "inadecuado",
    "adjetivo": "sustantivo",
    "admisible": "inadmisible",
    "adulto": "juvenil",
    "avanzar": "alejarse",
    "adelante": "marcha atrás",
    "frente": "posterior",
    "virar": "espalda",
    "ventaja": "desventaja",
    "afirmación": "inversión",
    "afirmativo": "negativo",
    "neutral": "negativo",
    "en popa": "delantero",
    "años": "rejuvenecer",
    "envejecido": "joven",
    "agitación": "calma",
    "de acuerdo": "discrepar",
    "agradable": "desagradable",
    "acuerdo": "desacuerdo",
    "alterado": "inalterado",
    "alterno": "opuesto",
    "aficionado": "profesional",
    "ambiguo": "inequívoco",
    "amistoso": "antipático",
    "anfibio": "terrestre",
    "anal": "oral",
    "análogo": "homólogo",
    "análisis": "síntesis",
    "analítico": "sintético",
    "antepasado": "descendiente",
    "angular": "redondeado",
    "animar": "quejar",
    "responder": "pregunta",
    "antagonista": "sinérgico",
    "antecedente": "subsecuente",
    "anterior": "subsiguiente",
    "antiséptico": "séptico",
    "apariencia": "desaparición",
    "apreciación": "depreciación",
    "aprobación": "desaprobación",
    "aprobar": "desaprobar",
    "acuático": "anfibio",
    "terrestre": "anfibio",
    "acuoso": "ígneo",
    "brazo": "desarmar",
    "armado": "desarmado",
    "llegar": "salir",
    "ascender": "descender",
    "ascenso": "descendencia",
    "dormido": "despierto",
    "asentir": "disentimiento",
    "asimetría": "simetría",
    "ateísmo": "teísmo",
    "adjuntar": "despegar",
    "ataque": "defender",
    "enjuiciar": "defender",
    "atención": "difuminar",
    "atracción": "repulsión",
    "audible": "inaudible",
    "aumento": "inferior",
    "tía": "tío",
    "autorizado": "no autorizado",
    "automático": "manual",
    "evitar": "confrontar",
    "despierto": "dormido",
    "espalda": "virar",
    "alejarse": "avanzar",
    "posterior": "anterior",
    "fondo": "parte superior",
    "hacia atrás": "adelante",
    "marcha atrás": "anverso",
    "malo": "bueno",
    "mal": "bueno",
    "maldad": "bondad",
    "equilibrado": "desequilibrado",
    "oso": "toro",
    "hermosa": "feo",
    "belleza": "fealdad",
    "empezar": "fin",
    "comenzando": "medio",
    "temprano": "tarde",
    "creencia": "incredulidad",
    "curva": "enderezar",
    "benigno": "maligno",
    "grande": "pequeña",
    "nacimiento": "muerte",
    "bisexual": "homosexual",
    "negro": "blanco",
    "bendecir": "maldición",
    "bendito": "maldito",
    "incruento": "sangriento",
    "sangriento": "incruento",
    "difuminar": "atención",
    "hervir": "congelar",
    "negrita": "tímido",
    "audacia": "timidez",
    "pedir prestado": "prestar",
    "prestatario": "prestador",
    "ligado": "sin consolidar",
    "chico": "niña",
    "boicotear": "patrocinar",
    "descanso": "reparar",
    "quebradizo": "irrompible",
    "aclarar": "oscurecer",
    "aligerar": "oscurecer",
    "roto": "intacto",
    "hermano": "hermana",
    "toro": "oso",
    "ocupado": "desocupado",
    "trabajo": "ocioso",
    "comprar": "vender",
    "calma": "agitación",
    "capaz": "incapaz",
    "efectivo": "crédito",
    "débito": "crédito",
    "centrar": "izquierda",
    "cerebral": "emocional",
    "certeza": "incertidumbre",
    "cambio": "permanecer",
    "salir": "llegar",
    "movimiento": "permanecer",
    "cambiable": "inmutable",
    "cambiado": "sin alterar",
    "cargar": "descarga",
    "conseguir": "descarga",
    "barato": "costoso",
    "alegre": "triste",
    "niño": "padre",
    "civil": "militar",
    "reclamación": "perder",
    "claridad": "opacidad",
    "prominencia": "oscuridad",
    "transparencia": "opacidad",
    "limpiar": "inmundo",
    "clero": "laicado",
    "clérigo": "lego",
    "cerca": "abierto",
    "cerrado": "abierto",
    "cerrar": "abierto",
    "cercanía": "franqueza",
    "costero": "interior",
    "coherente": "incoherente",
    "frío": "caliente",
    "colateral": "lineal",
    "comedia": "tragedia",
    "comodidad": "incomodidad",
    "común": "poco común",
    "compatible": "incompatible",
    "competencia": "cooperación",
    "competente": "incompetente",
    "quejar": "animar",
    "lo completo": "incompletitud",
    "complejo": "sencillo",
    "compuesto": "sencillo",
    "obediente": "desobediente",
    "complicar": "simplificar",
    "cóncavo": "convexo",
    "presunción": "humildad",
    "orgullo": "humildad",
    "concentración": "distribución",
    "concéntrico": "excéntrico",
    "concepción": "idea equivocada",
    "preocupado": "despreocupado",
    "hormigón": "abstracto",
    "confirmado": "inconfirmado",
    "confrontar": "evitar",
    "conjuntivo": "disyuntivo",
    "conectar": "desconectar",
    "conectado": "desconectado",
    "conciencia": "inconsciencia",
    "conservador": "liberal",
    "conservar": "residuos",
    "considerado": "desconsiderado",
    "consistencia": "inconsecuencia",
    "consonante": "vocal",
    "conspicuo": "discreto",
    "constitucional": "inconstitucional",
    "consumir": "abstenerse",
    "contenido": "desenfrenado",
    "continuo": "discontinuo",
    "continuación": "discontinuación",
    "continuar": "discontinuar",
    "continuidad": "discontinuidad",
    "contrato": "expandir",
    "contratado": "expandido",
    "contracción": "expansión",
    "conveniente": "inconveniente",
    "convencional": "poco convencional",
    "converger": "divergir",
    "convergencia": "divergencia",
    "convergente": "divergente",
    "convexo": "cóncavo",
    "convencido": "no convencido",
    "guay": "calor",
    "cooperación": "competencia",
    "cosmopolita": "provincial",
    "valor": "cobardía",
    "cubrir": "descubrir",
    "encubierto": "abierto",
    "cobardía": "valor",
    "crédito": "débito",
    "acreedor": "deudor",
    "criticar": "alabanza",
    "llorar": "risa",
    "curable": "incurable",
    "maldición": "bendecir",
    "maldito": "bendito",
    "curvo": "derecho",
    "cortar": "sin cortar",
    "peligro": "la seguridad",
    "peligroso": "seguro",
    "oscuro": "ligero",
    "oscurecer": "aligerar",
    "oscuridad": "prominencia",
    "pesadez": "ligereza",
    "hija": "hijo",
    "día": "noche",
    "sordo": "audición",
    "muerte": "nacimiento",
    "deudor": "acreedor",
    "decencia": "indecencia",
    "bueno": "mal",
    "caduco": "hojas perennes",
    "decisión": "indecisión",
    "decisivo": "indeciso",
    "disminución": "aumento",
    "disminuido": "aumentado",
    "decremento": "incremento",
    "derrota": "victoria",
    "defender": "enjuiciar",
    "acusado": "demandante",
    "defensa": "enjuiciamiento",
    "defensivo": "ofensiva",
    "desafiante": "obediente",
    "déficit": "dirigir",
    "definido": "indefinido",
    "deflación": "inflación",
    "retrasar": "prisa",
    "persistir": "prisa",
    "demanda": "suministro",
    "negar": "reclamación",
    "rechazar": "aceptar",
    "dependiente": "independiente",
    "depositar": "retirar",
    "depreciación": "apreciación",
    "deprimente": "alegre",
    "descender": "ascender",
    "descendiente": "antepasado",
    "descendencia": "ascenso",
    "descriptivo": "preceptivo",
    "deseable": "indeseable",
    "desesperación": "esperanza",
    "desesperado": "esperanza",
    "destruido": "preservado",
    "despegar": "adjuntar",
    "devolución": "evolución",
    "diferir de": "igual",
    "desigual": "igual",
    "diferencia": "igualdad",
    "difícil": "oferta",
    "dificultad": "facilitar",
    "diligente": "negligente",
    "dilución": "concentración",
    "distribución": "concentración",
    "sucio": "limpiar",
    "inmundo": "limpiar",
    "inhabilitar": "habilitar",
    "desventaja": "ventaja",
    "discrepar": "de acuerdo",
    "desagradable": "sabroso",
    "desacuerdo": "acuerdo",
    "desaparición": "apariencia",
    "desaprobación": "aprobación",
    "desaprobar": "aprobar",
    "desarmar": "brazo",
    "descarga": "conseguir",
    "perder": "golpear",
    "incomodidad": "comodidad",
    "desconectar": "conectar",
    "descontento": "contenido",
    "discontinuación": "continuación",
    "discontinuar": "continuar",
    "discontinuidad": "continuidad",
    "discontinuo": "continuo",
    "desalentar": "alentar",
    "desánimo": "ánimo",
    "desacoplar": "contratar",
    "deshonesto": "honesto",
    "deshonestidad": "honestidad",
    "deshonra": "honor",
    "desinfectar": "infectar",
    "desintegrarse": "integrar",
    "disyuntivo": "conjuntivo",
    "disgusto": "gusto",
    "desalojar": "presentar",
    "desobediencia": "obediencia",
    "desobediente": "obediente",
    "desobedecer": "obedecer",
    "trastorno": "orden",
    "desordenado": "ordenado",
    "desestructurado": "organizado",
    "desorganizado": "organizado",
    "disgustado": "satisfecho",
    "refutar": "probar",
    "descalificar": "calificar",
    "de mala fama": "acreditado",
    "mala fama": "reputación",
    "falta de respeto": "el respeto",
    "irrespetuoso": "respetuoso",
    "insatisfacción": "satisfacción",
    "disentimiento": "asentir",
    "deservicio": "servicio",
    "disímil": "similar",
    "disonancia": "armonía",
    "disuadir": "persuadir",
    "distal": "proximal",
    "distante": "cerca",
    "abierto": "encubierto",
    "distinguible": "indistinguible",
    "desconfianza": "confianza",
    "diurno": "nocturno",
    "divergir": "converger",
    "divergencia": "convergencia",
    "divergente": "convergente",
    "dividir": "unir",
    "individualmente": "multiplicar",
    "dividido": "unido",
    "divisible": "indivisible",
    "nacional": "internacional",
    "nativo": "exterior",
    "dominante": "subordinar",
    "latente": "activo",
    "extinto": "existente",
    "inactivo": "activo",
    "pasivo": "activo",
    "tranquilo": "ruidoso",
    "doble": "soltero",
    "múltiple": "soltero",
    "paloma": "halcón",
    "dramático": "lírica",
    "seco": "mojado",
    "agrio": "endulzar",
    "debido": "indebido",
    "aburrido": "afilar",
    "aplanar": "afilar",
    "moribundo": "naciente",
    "terrenal": "celestial",
    "facilitar": "dificultad",
    "fácil": "difícil",
    "reflujo": "marea",
    "excéntrico": "concéntrico",
    "educado": "deseducado",
    "eficaz": "ineficaz",
    "eficiencia": "ineficacia",
    "eficiente": "ineficiente",
    "salida": "entrar",
    "elástico": "no elástico",
    "elegible": "inelegible",
    "emocional": "cerebral",
    "empírico": "teórico",
    "vacío": "completo",
    "delgado": "espesar",
    "habilitar": "inhabilitar",
    "alentar": "desalentar",
    "ánimo": "desánimo",
    "fin": "comenzando",
    "finalizando": "comenzando",
    "medio": "temprano",
    "endémico": "cosmopolita",
    "provincial": "cosmopolita",
    "energético": "letárgico",
    "hacer cumplir": "eximir",
    "contratar": "desacoplar",
    "disfrutar": "sufrir",
    "entrar": "salida",
    "igual": "desigual",
    "igualdad": "diferencia",
    "ecuatorial": "polar",
    "equitativo": "injusto",
    "equívoco": "inequívoco",
    "borrar": "grabar",
    "establecer": "abolir",
    "memorable": "sin acontecimientos notables",
    "hojas perennes": "caduco",
    "evolución": "devolución",
    "exclusión": "inclusión",
    "eximir": "hacer cumplir",
    "exhalar": "inhalar",
    "expandir": "contrato",
    "expandido": "contratado",
    "expansión": "contracción",
    "esperado": "inesperado",
    "costoso": "barato",
    "experimentado": "inexperto",
    "exportar": "importar",
    "exprimir": "local",
    "general": "específico",
    "extensión": "flexión",
    "exterior": "nativo",
    "externo": "interno",
    "externamente": "internamente",
    "extinguir": "encender",
    "extramuros": "intramuros",
    "extraordinario": "ordinario",
    "extrínseco": "intrínseco",
    "defecto": "paso",
    "corriendo": "en pie",
    "fracaso": "éxito",
    "justa": "injusto",
    "fiel": "infiel",
    "otoño": "subir",
    "conjunto": "subir",
    "falible": "infalible",
    "que cae": "creciente",
    "falsedad": "verdad",
    "fama": "infamia",
    "familiar": "desconocido",
    "lujoso": "llanura",
    "grasa": "delgado",
    "completo": "vacío",
    "grueso": "delgado",
    "espesar": "delgado",
    "padre": "niño",
    "fauna": "flora",
    "favorable": "desfavorable",
    "federal": "unitario",
    "hembra": "masculino",
    "femenino": "neutro",
    "feminidad": "masculinidad",
    "fértil": "estéril",
    "fidelidad": "infidelidad",
    "figura": "suelo",
    "llenar": "vacío",
    "encontrar": "perder",
    "terminar": "comienzo",
    "detener": "comienzo",
    "finito": "infinito",
    "fuego": "alquiler",
    "flexión": "extensión",
    "flotador": "lavabo",
    "fuente": "lavabo",
    "flora": "fauna",
    "enemigo": "amigo",
    "doblez": "desplegar",
    "seguir": "preceder",
    "tener éxito": "preceder",
    "seguidor": "líder",
    "locura": "cordura",
    "tonto": "sabio",
    "pie": "cabeza",
    "cola": "cabeza",
    "prohibir": "permiso",
    "delantero": "en popa",
    "primer plano": "fondo",
    "olvidar": "recuerda",
    "indulgente": "implacable",
    "formalismo": "imitación",
    "afortunado": "desgraciado",
    "anverso": "marcha atrás",
    "falta": "justa",
    "injusto": "equitativo",
    "encontró": "perdió",
    "fraternal": "idéntico",
    "congelar": "hervir",
    "frecuente": "infrecuente",
    "frecuentemente": "con poca frecuencia",
    "amigo": "enemigo",
    "cabeza": "cola",
    "plenitud": "vacío",
    "funcional": "orgánico",
    "inorgánico": "orgánico",
    "ganancia": "pérdida",
    "gaseoso": "sólido",
    "hueco": "sólido",
    "reunir": "untado",
    "generalidad": "particularidad",
    "generoso": "tacaño",
    "niña": "chico",
    "bondad": "maldad",
    "gradual": "repentino",
    "agradecido": "desagradecido",
    "mayor": "júnior",
    "verde": "maduro",
    "bruto": "red",
    "suelo": "figura",
    "culpa": "inocencia",
    "culpable": "inocente",
    "felizmente": "tristemente",
    "felicidad": "infelicidad",
    "contento": "infeliz",
    "dureza": "blandura",
    "volumen": "blandura",
    "nitidez": "blandura",
    "armonía": "disonancia",
    "odio": "amor",
    "odioso": "amable",
    "halcón": "paloma",
    "saludable": "insalubre",
    "audición": "sordo",
    "calor": "guay",
    "celestial": "terrenal",
    "heterogeneidad": "homogeneidad",
    "esconder": "espectáculo",
    "alquiler": "fuego",
    "golpear": "perder",
    "santo": "impío",
    "homogeneidad": "heterogeneidad",
    "homólogo": "análogo",
    "homosexual": "bisexual",
    "honesto": "deshonesto",
    "honestidad": "deshonestidad",
    "honor": "deshonra",
    "esperanza": "desesperación",
    "esperanzado": "sin esperanza",
    "sin esperanza": "esperanzado",
    "horizontal": "vertical",
    "hostil": "amistoso",
    "antipático": "amistoso",
    "caliente": "frío",
    "humilde": "orgulloso",
    "humildad": "orgullo",
    "hambriento": "sediento",
    "idéntico": "fraternal",
    "ocioso": "trabajo",
    "ígneo": "acuoso",
    "encender": "extinguir",
    "ignorar": "darse cuenta",
    "ilegal": "legal",
    "ilegalidad": "legalidad",
    "ilegible": "legible",
    "ilógico": "lógico",
    "imitación": "formalismo",
    "inmaterial": "material",
    "inmadurez": "madurez",
    "inconmensurable": "mensurable",
    "inmoral": "moral",
    "inmoralidad": "moralidad",
    "inmortal": "mortal",
    "inmortalidad": "mortalidad",
    "inmutable": "cambiable",
    "imparcialidad": "parcialidad",
    "infranqueable": "pasable",
    "impaciencia": "paciencia",
    "impaciente": "paciente",
    "imperceptible": "perceptible",
    "imperfección": "perfección",
    "impermeable": "permeable",
    "inadmisible": "admisible",
    "impersonal": "personal",
    "descortés": "cortés",
    "importar": "exportar",
    "importante": "sin importancia",
    "imposibilidad": "posibilidad",
    "impotente": "poderoso",
    "improbable": "probable",
    "mejorado": "no mejorado",
    "mejora": "disminución",
    "imprudente": "prudente",
    "impureza": "pureza",
    "incapacidad": "capacidad",
    "inaccesible": "accesible",
    "incorrecto": "preciso",
    "en acción": "acción",
    "inactividad": "actividad",
    "inadecuado": "adecuado",
    "inanimado": "animar",
    "inatención": "atención",
    "inaudible": "audible",
    "incapaz": "capaz",
    "inclinado": "horizontal",
    "vertical": "horizontal",
    "inclusión": "exclusión",
    "incoherente": "coherente",
    "incompatible": "compatible",
    "incompetencia": "competencia",
    "incompetente": "competente",
    "incompletitud": "lo completo",
    "desconsiderado": "pensativo",
    "inconsecuencia": "consistencia",
    "discreto": "conspicuo",
    "inconveniente": "conveniente",
    "incrementar": "disminución",
    "aumentado": "disminuido",
    "incremento": "decremento",
    "incurable": "curable",
    "indecencia": "decencia",
    "indecente": "bueno",
    "indecisión": "decisión",
    "indeciso": "decisivo",
    "independiente": "dependiente",
    "indistinguible": "distinguible",
    "indivisible": "divisible",
    "interior": "exterior",
    "ineficaz": "eficaz",
    "ineficacia": "eficiencia",
    "ineficiente": "eficiente",
    "no elástico": "elástico",
    "inelegible": "elegible",
    "desigualdad": "igualdad",
    "inexperto": "entrenado",
    "infalible": "falible",
    "infamia": "fama",
    "infectar": "desinfectar",
    "inferior": "aumento",
    "inferioridad": "superioridad",
    "infidelidad": "fidelidad",
    "infinito": "finito",
    "inflación": "deflación",
    "informado": "no informado",
    "infrecuente": "frecuente",
    "con poca frecuencia": "frecuentemente",
    "ingreso": "salida",
    "poblado": "deshabitado",
    "inhalar": "exhalar",
    "injusticia": "justicia",
    "inocencia": "culpa",
    "inocente": "culpable",
    "inocuo": "nocivo",
    "inoperante": "operatorio",
    "insano": "cuerdo",
    "inseguridad": "seguridad",
    "insignificancia": "significado",
    "insignificante": "significativo",
    "insoluble": "soluble",
    "insolvencia": "solvencia",
    "insolvente": "solvente",
    "inestabilidad": "estabilidad",
    "instrumental": "vocal",
    "insuficiencia": "suficiencia",
    "insuficiente": "suficiente",
    "insuficientemente": "suficientemente",
    "integrar": "desintegrarse",
    "integración": "segregación",
    "inteligencia": "estupidez",
    "inteligible": "ininteligible",
    "destinado a": "involuntaria",
    "intencionalmente": "involuntariamente",
    "interesado": "desinteresado",
    "interesante": "poco interesante",
    "intermedio": "terminal",
    "interno": "externo",
    "internamente": "externamente",
    "internacional": "nacional",
    "local": "general",
    "intolerancia": "tolerancia",
    "intolerante": "tolerante",
    "intratable": "manejable",
    "intramuros": "extramuros",
    "intrínseco": "extrínseco",
    "invisibilidad": "visibilidad",
    "invisible": "visible",
    "involuntario": "voluntario",
    "irracional": "racional",
    "irregular": "regular",
    "irregularidad": "regularidad",
    "irrelevante": "pertinente",
    "irresponsable": "responsable",
    "irreverente": "reverente",
    "problema": "recordar",
    "articulación": "separar",
    "alegría": "dolor",
    "júnior": "mayor",
    "justicia": "injusticia",
    "juvenil": "adulto",
    "kern": "kern",
    "tipo": "cruel",
    "rey": "reina",
    "laicado": "clero",
    "tarde": "temprano",
    "risa": "llorar",
    "legal": "ilegal",
    "flojo": "tiempo",
    "relajado": "tiempo",
    "lego": "clérigo",
    "dirigir": "déficit",
    "líder": "seguidor",
    "izquierda": "centrar",
    "legalidad": "ilegalidad",
    "legalizar": "proscrito",
    "legible": "ilegible",
    "prestar": "pedir prestado",
    "prestador": "prestatario",
    "alargar": "acortar",
    "menor": "mayor",
    "letárgico": "energético",
    "nivel": "aumento",
    "liberal": "conservador",
    "mentira": "estar",
    "rendimiento": "estar",
    "ligero": "oscuro",
    "ligereza": "pesadez",
    "gusto": "disgusto",
    "limitado": "ilimitado",
    "lineal": "colateral",
    "líquido": "gaseoso",
    "sólido": "hueco",
    "específico": "general",
    "ubicación": "estudio",
    "bloquear": "desbloquear",
    "presentar": "desalojar",
    "lógico": "ilógico",
    "largo": "corto",
    "alto": "corto",
    "aflojar": "endurecer",
    "pérdida": "ganancia",
    "perdió": "encontró",
    "amable": "odioso",
    "amor": "odio",
    "suerte": "desafortunado",
    "lírica": "dramático",
    "mayoria": "minoría",
    "hacer": "descanso",
    "reparar": "descanso",
    "masculino": "femenino",
    "maligno": "benigno",
    "manual": "automático",
    "marcado": "no notificado",
    "casado": "soltero",
    "neutro": "femenino",
    "masculinidad": "feminidad",
    "máscara": "desenmascarar",
    "material": "inmaterial",
    "materno": "paternal",
    "madurez": "inmadurez",
    "máximo": "mínimo",
    "mensurable": "inconmensurable",
    "mental": "físico",
    "misericordioso": "despiadado",
    "despiadado": "misericordioso",
    "militar": "civil",
    "mente": "olvidar",
    "recuerda": "olvidar",
    "mínimo": "máximo",
    "minoría": "mayoria",
    "idea equivocada": "concepción",
    "molar": "molecular",
    "molecular": "molar",
    "moral": "inmoral",
    "moralidad": "inmoralidad",
    "mortal": "inmortal",
    "mortalidad": "inmortalidad",
    "madre": "padre",
    "multiplicar": "individualmente",
    "unir": "dividir",
    "mudable": "inmutable",
    "nadir": "cenit",
    "estrecho": "ensanchar",
    "naciente": "moribundo",
    "negativo": "neutral",
    "negligente": "diligente",
    "sobrino": "sobrina",
    "red": "bruto",
    "sobrina": "sobrino",
    "noche": "día",
    "nocturno": "diurno",
    "nominal": "real",
    "irreal": "real",
    "inexistente": "existente",
    "normal": "anormal",
    "darse cuenta": "ignorar",
    "nocivo": "inocuo",
    "numérico": "verbal",
    "obediencia": "desobediencia",
    "obedecer": "desobedecer",
    "objetivo": "subjetivo",
    "obligatorio": "opcional",
    "oblicuo": "perpendicular",
    "opacidad": "transparencia",
    "ofensa": "defensa",
    "enjuiciamiento": "defensa",
    "ofensiva": "defensivo",
    "oficial": "no oficial",
    "franqueza": "cercanía",
    "operatorio": "inoperante",
    "opuesto": "alterno",
    "optimismo": "pesimismo",
    "optimista": "pesimista",
    "opcional": "obligatorio",
    "oral": "anal",
    "orden": "trastorno",
    "ordenado": "desordenado",
    "ordinario": "extraordinario",
    "orgánico": "inorgánico",
    "organizado": "desorganizado",
    "ortodoxo": "heterodoxo",
    "al aire libre": "interior",
    "proscrito": "legalizar",
    "sobreestimar": "subestimar",
    "gastos generales": "superficie",
    "paquete": "deshacer",
    "doloroso": "sin dolor",
    "sin dolor": "doloroso",
    "paralela": "oblicuo",
    "perpendicular": "oblicuo",
    "parcialidad": "imparcialidad",
    "particularidad": "generalidad",
    "parcialmente": "totalmente",
    "pasable": "infranqueable",
    "paso": "corriendo",
    "en pie": "corriendo",
    "pasado": "futuro",
    "presente": "ausente",
    "paternal": "materno",
    "paciencia": "impaciencia",
    "paciente": "impaciente",
    "patrocinar": "boicotear",
    "paz": "guerra",
    "pena": "recompensa",
    "perceptible": "imperceptible",
    "perfección": "imperfección",
    "permeable": "impermeable",
    "permisible": "inadmisible",
    "permisivo": "preventivo",
    "permiso": "prohibir",
    "personal": "impersonal",
    "persuadir": "disuadir",
    "pesimismo": "optimismo",
    "pesimista": "optimista",
    "físico": "mental",
    "llanura": "lujoso",
    "demandante": "acusado",
    "satisfecho": "disgustado",
    "plural": "singular",
    "polar": "ecuatorial",
    "cortés": "descortés",
    "popular": "impopular",
    "porosidad": "solidez",
    "posibilidad": "imposibilidad",
    "potente": "impotente",
    "potencial": "real",
    "pobreza": "riqueza",
    "poderoso": "impotente",
    "alabanza": "criticar",
    "preceder": "tener éxito",
    "prefijo": "sufijo",
    "preparación": "resolución",
    "preparado": "desprevenido",
    "preceptivo": "descriptivo",
    "presencia": "ausencia",
    "preservado": "destruido",
    "preventivo": "permisivo",
    "primario": "secundario",
    "privado": "público",
    "en privado": "en público",
    "probable": "improbable",
    "productivo": "improductivo",
    "profano": "sagrado",
    "profesional": "aficionado",
    "progreso": "regreso",
    "progresivo": "regresivo",
    "protegido": "desprotegido",
    "orgulloso": "humilde",
    "probar": "refutar",
    "proximal": "distal",
    "próximo": "último",
    "prudente": "imprudente",
    "público": "privado",
    "en público": "en privado",
    "publicado": "inédito",
    "halar": "empujar",
    "puntualidad": "tardanza",
    "purga": "rehabilitar",
    "pureza": "impureza",
    "empujar": "halar",
    "calificar": "descalificar",
    "reina": "rey",
    "pregunta": "responder",
    "cuestionable": "incuestionable",
    "con rapidez": "despacio",
    "racional": "irracional",
    "realista": "poco realista",
    "tranquilizar": "preocupación",
    "recordar": "problema",
    "grabar": "borrar",
    "estribillo": "acto",
    "desperdicios": "aceptar",
    "regreso": "progreso",
    "regresivo": "progresivo",
    "regular": "irregular",
    "regularidad": "irregularidad",
    "regulado": "no regulado",
    "rehabilitar": "purga",
    "rechazo": "aceptación",
    "rejuvenecer": "años",
    "relacionado": "no relacionado",
    "relativo": "absoluto",
    "pertinente": "irrelevante",
    "de confianza": "no fidedigno",
    "religioso": "secular",
    "repulsión": "atracción",
    "acreditado": "de mala fama",
    "reputación": "mala fama",
    "resistir": "rendición",
    "resolución": "preparación",
    "el respeto": "falta de respeto",
    "respetuoso": "irrespetuoso",
    "responsable": "irresponsable",
    "restringido": "irrestricto",
    "retrospectivo": "futuro",
    "reverente": "irreverente",
    "inversión": "afirmación",
    "recompensa": "pena",
    "paseo": "caminar",
    "maduro": "verde",
    "subir": "conjunto",
    "creciente": "que cae",
    "rotor": "estator",
    "aspereza": "suavidad",
    "redondo": "cuadrado",
    "redondeado": "angular",
    "rural": "urbano",
    "prisa": "persistir",
    "sagrado": "profano",
    "tristemente": "felizmente",
    "tristeza": "felicidad",
    "infelicidad": "felicidad",
    "seguro": "peligroso",
    "la seguridad": "peligro",
    "cuerdo": "insano",
    "cordura": "locura",
    "satisfacción": "insatisfacción",
    "sabroso": "insípido",
    "escaso": "abundante",
    "escasez": "abundancia",
    "científico": "no científico",
    "escrupuloso": "poco escrupuloso",
    "secundario": "primario",
    "secular": "religioso",
    "seguridad": "inseguridad",
    "segregación": "integración",
    "egoísta": "altruista",
    "vender": "comprar",
    "separar": "articulación",
    "separación": "unión",
    "séptico": "antiséptico",
    "servicio": "deservicio",
    "colocado": "inestable",
    "afilar": "aplanar",
    "corto": "alto",
    "acortar": "alargar",
    "gritar": "susurro",
    "espectáculo": "esconder",
    "encogimiento": "tramo",
    "lado": "fondo",
    "parte superior": "fondo",
    "significado": "insignificancia",
    "significativo": "insignificante",
    "similar": "disímil",
    "sencillo": "compuesto",
    "simplificar": "complicar",
    "soltero": "casado",
    "singular": "plural",
    "lavabo": "fuente",
    "hermana": "hermano",
    "dormir": "despertar",
    "despacio": "con rapidez",
    "pequeña": "grande",
    "suavidad": "aspereza",
    "blandura": "nitidez",
    "solidez": "porosidad",
    "soluble": "insoluble",
    "solvencia": "insolvencia",
    "solvente": "insolvente",
    "hijo": "hija",
    "dolor": "alegría",
    "triste": "alegre",
    "hablado": "escrito",
    "no escrito": "escrito",
    "esporádico": "continuo",
    "untado": "reunir",
    "cuadrado": "redondo",
    "estabilidad": "inestabilidad",
    "estable": "inestable",
    "estar": "rendimiento",
    "comienzo": "detener",
    "estator": "rotor",
    "permanecer": "movimiento",
    "escarpado": "gradual",
    "repentino": "gradual",
    "estéril": "fértil",
    "endurecer": "aflojar",
    "tacaño": "generoso",
    "tormentoso": "calma",
    "derecho": "curvo",
    "enderezar": "curva",
    "desconocido": "familiar",
    "fuerza": "debilidad",
    "tramo": "encogimiento",
    "fuertemente": "enclenque",
    "estudio": "ubicación",
    "estupidez": "inteligencia",
    "subjetivo": "objetivo",
    "subordinar": "dominante",
    "subsecuente": "antecedente",
    "sustantivo": "adjetivo",
    "sustraer": "añadir",
    "sustracción": "adición",
    "subsiguiente": "anterior",
    "éxito": "fracaso",
    "exitoso": "fracasado",
    "sucumbir": "sobrevivir",
    "sufrir": "disfrutar",
    "suficiencia": "insuficiencia",
    "suficiente": "insuficiente",
    "suficientemente": "insuficientemente",
    "sufijo": "prefijo",
    "amanecer": "puesta de sol",
    "puesta de sol": "amanecer",
    "superior": "inferior",
    "superioridad": "inferioridad",
    "suministro": "demanda",
    "soportado": "sin soporte",
    "superficie": "gastos generales",
    "rendición": "resistir",
    "sobrevivir": "sucumbir",
    "dulce": "agrio",
    "mojado": "seco",
    "endulzar": "agrio",
    "simetría": "asimetría",
    "simpático": "no simpático",
    "sinérgico": "antagonista",
    "síntesis": "análisis",
    "sintético": "analítico",
    "tardanza": "puntualidad",
    "de buen gusto": "insípido",
    "insípido": "sabroso",
    "oferta": "difícil",
    "tiempo": "relajado",
    "terminal": "intermedio",
    "teísmo": "ateísmo",
    "teórico": "empírico",
    "sediento": "hambriento",
    "pensativo": "desconsiderado",
    "ahorrativo": "antieconómico",
    "marea": "reflujo",
    "corbata": "desatar",
    "tímido": "negrita",
    "timidez": "audacia",
    "tolerancia": "intolerancia",
    "tolerante": "intolerante",
    "dentada": "sin dientes",
    "sin dientes": "dentada",
    "tocado": "intacto",
    "manejable": "intratable",
    "tragedia": "comedia",
    "entrenado": "inexperto",
    "confianza": "desconfianza",
    "verdad": "falsedad",
    "fealdad": "belleza",
    "feo": "hermosa",
    "último": "próximo",
    "inaceptable": "aceptable",
    "no reconocido": "admitido",
    "inalterado": "alterado",
    "inequívoco": "equívoco",
    "desarmado": "armado",
    "no autorizado": "autorizado",
    "desequilibrado": "equilibrado",
    "incredulidad": "creencia",
    "sin consolidar": "ligado",
    "irrompible": "quebradizo",
    "intacto": "tocado",
    "incertidumbre": "certeza",
    "sin alterar": "cambiado",
    "tío": "tía",
    "poco común": "común",
    "despreocupado": "preocupado",
    "inconfirmado": "confirmado",
    "desconectado": "conectado",
    "inconsciencia": "conciencia",
    "inconstitucional": "constitucional",
    "poco convencional": "convencional",
    "no convencido": "convencido",
    "descubrir": "cubrir",
    "sin cortar": "cortar",
    "indefinido": "definido",
    "subestimar": "sobreestimar",
    "indeseable": "deseable",
    "indebido": "debido",
    "deseducado": "educado",
    "sin acontecimientos notables": "memorable",
    "inesperado": "esperado",
    "infiel": "fiel",
    "desfavorable": "favorable",
    "desplegar": "doblez",
    "implacable": "indulgente",
    "desgraciado": "afortunado",
    "desagradecido": "agradecido",
    "infeliz": "contento",
    "insalubre": "saludable",
    "impío": "santo",
    "sin importancia": "importante",
    "no mejorado": "mejorado",
    "no informado": "informado",
    "deshabitado": "poblado",
    "ininteligible": "inteligible",
    "involuntaria": "destinado a",
    "involuntariamente": "intencionalmente",
    "desinteresado": "interesado",
    "poco interesante": "interesante",
    "unión": "separación",
    "unitario": "federal",
    "unido": "dividido",
    "cruel": "tipo",
    "ilimitado": "limitado",
    "desbloquear": "bloquear",
    "desafortunado": "suerte",
    "no notificado": "marcado",
    "desenmascarar": "máscara",
    "desocupado": "ocupado",
    "no oficial": "oficial",
    "sin oposición": "opuesto",
    "heterodoxo": "ortodoxo",
    "deshacer": "paquete",
    "impopular": "popular",
    "desprevenido": "preparado",
    "improductivo": "productivo",
    "desprotegido": "protegido",
    "inédito": "publicado",
    "incuestionable": "cuestionable",
    "poco realista": "realista",
    "no regulado": "regulado",
    "no relacionado": "relacionado",
    "no fidedigno": "de confianza",
    "desenfrenado": "contenido",
    "irrestricto": "restringido",
    "no científico": "científico",
    "poco escrupuloso": "escrupuloso",
    "altruista": "egoísta",
    "inestable": "estable",
    "fracasado": "exitoso",
    "sin soporte": "soportado",
    "no simpático": "simpático",
    "desatar": "corbata",
    "raro": "usual",
    "quitar el velo": "velo",
    "incauto": "cauteloso",
    "a regañadientes": "de buena gana",
    "renuencia": "complacencia",
    "relajarse": "viento",
    "indigno de": "digno",
    "urbano": "rural",
    "usual": "raro",
    "valioso": "sin valor",
    "velo": "quitar el velo",
    "verbal": "numérico",
    "victoria": "derrota",
    "virtuoso": "malvado",
    "visibilidad": "invisibilidad",
    "visible": "invisible",
    "vocal": "consonante",
    "voluntario": "involuntario",
    "despertar": "dormir",
    "caminar": "paseo",
    "menguar": "cera",
    "guerra": "paz",
    "cauteloso": "incauto",
    "residuos": "conservar",
    "antieconómico": "ahorrativo",
    "cera": "menguar",
    "enclenque": "fuertemente",
    "debilidad": "fuerza",
    "riqueza": "pobreza",
    "ingrávido": "pesado",
    "pesado": "ingrávido",
    "susurro": "gritar",
    "blanco": "negro",
    "totalmente": "parcialmente",
    "malvado": "virtuoso",
    "amplio": "estrecho",
    "ensanchar": "estrecho",
    "de buena gana": "a regañadientes",
    "complacencia": "renuencia",
    "viento": "relajarse",
    "sabiduría": "locura",
    "sabio": "tonto",
    "retirar": "depositar",
    "preocupación": "tranquilizar",
    "sin valor": "valioso",
    "digno": "indigno de",
    "escrito": "no escrito",
    "joven": "envejecido",
    "cenit": "nadir",
}
